@@ -4,6 +4,7 @@
 #include <QTimer>
 #include <QTime>
 #include <QSettings>
+#include <QPainter>
 
 #include "settingsdlg.h"
 
@@ -45,6 +46,8 @@ dCalWidget::dCalWidget() : QWidget()
 
 void dCalWidget::renewCalendar()
 {
+  update();
+
   QSettings settings;
 
   names = QColor(settings.value("color.names", "#FF0").toString());
@@ -112,3 +115,19 @@ void dCalWidget::showSettingsDialog()
   sdlg.exec();
   renewCalendar();
 }
+
+void dCalWidget::paintEvent(QPaintEvent *event)
+{
+  QWidget::paintEvent(event);
+
+  QSettings settings;
+
+  QColor back = QColor(settings.value("color.widgetback", "#000").toString());
+  back.setAlpha(settings.value("back.transparence", "100").toInt());
+
+  QPainter p(this);
+  p.setBrush(back);
+  p.setPen(Qt::NoPen);
+  p.drawRoundedRect(rect(), 25, 25);
+  p.end();
+}
