@@ -14,7 +14,8 @@ public:
     ~SettingsDialog();
 
 private:
-    ColorButton *names, *days, *weekends, *weeks, *cday, *cdayback;
+    ColorButton *names, *days, *weekends, *weeks, *cday, *cdayback, *widgetback;
+    QSlider *transparence;
     QComboBox *lang;
 
 private slots:
